==> ncbi-vdb_2.11.2+dfsg.orig.tar.xz: ncbi-vdb-2.11.2/libs/cloud/aws-priv.h <==
/*==============================================================================
*
*                            PUBLIC DOMAIN NOTICE
*               National Center for Biotechnology Information
*
*  This software/database is a "United States Government Work" under the
*  terms of the United States Copyright Act.  It was written as part of
*  the author's official duties as a United States Government employee and
*  thus cannot be copyrighted.  This software/database is freely available
*  to the public for use. The National Library of Medicine and the U.S.
*  Government have not placed any restriction on its use or reproduction.
*
*  Although all reasonable efforts have been taken to ensure the accuracy
*  and reliability of the software and data, the NLM and the U.S.
*  Government do not and cannot warrant the performance or results that
*  may be obtained by using this software or data. The NLM and the U.S.
*  Government disclaim all warranties, express or implied, including
*  warranties of performance, merchantability or fitness for any particular
*  purpose.
*
*  Please cite the author in any work or product based on this material.
*
* =========================================================================== */

#pragma once

#ifndef _h_kfc_defs_
#include <kfc/defs.h> /* rc_t */
#endif

#ifdef __cplusplus
extern "C" {
#endif

struct AWS;
struct KClientHttpRequest;

rc_t AWSDoAuthentication(const struct AWS * self,
    struct KClientHttpRequest * req, const char * http_method,
    bool requester_payer);

/* exposed private functions for unit testing */

rc_t MakeAwsAuthenticationHeader(
    const char *AWSAccessKeyId,
    const char *YourSecretAccessKeyID,
    const char *StringToSign,
    char *dst, size_t dlen);

rc_t Base64InIdentityDocument(const char *src, char *dst, size_t dlen);
rc_t WrapInIdentityPkcs7(const char *src, char *dst, size_t dlen);
rc_t Base64InIdentityPkcs7(const char *src, char *dst, size_t dlen);
rc_t MakeLocation(const char *pkcs7, const char *document,
    char *dst, size_t dlen);

#ifdef __cplusplus
}
#endif

==> ncbi-vdb_3.2.1+dfsg.orig.tar.xz: ncbi-vdb-3.2.1/libs/cloud/aws-priv.h <==
/*==============================================================================
*
*                            PUBLIC DOMAIN NOTICE
*               National Center for Biotechnology Information
*
*  This software/database is a "United States Government Work" under the
*  terms of the United States Copyright Act.  It was written as part of
*  the author's official duties as a United States Government employee and
*  thus cannot be copyrighted.  This software/database is freely available
*  to the public for use. The National Library of Medicine and the U.S.
*  Government have not placed any restriction on its use or reproduction.
*
*  Although all reasonable efforts have been taken to ensure the accuracy
*  and reliability of the software and data, the NLM and the U.S.
*  Government do not and cannot warrant the performance or results that
*  may be obtained by using this software or data. The NLM and the U.S.
*  Government disclaim all warranties, express or implied, including
*  warranties of performance, merchantability or fitness for any particular
*  purpose.
*
*  Please cite the author in any work or product based on this material.
*
* =========================================================================== */

#pragma once

#ifndef _h_kfc_defs_
#include <kfc/defs.h> /* rc_t */
#endif

#ifdef __cplusplus
extern "C" {
#endif

struct AWS;
struct KClientHttpRequest;

rc_t AWSDoAuthentication(const struct AWS * self,
    struct KClientHttpRequest * req, const char * http_method,
    bool requester_payer);

/* exposed private functions for unit testing */

rc_t MakeAwsAuthenticationHeader(
    const char *AWSAccessKeyId,
    const char *YourSecretAccessKeyID,
    const char *StringToSign,
    char *dst, size_t dlen);

rc_t Base64InIdentityDocument(const char *src, char *dst, size_t dlen);
rc_t WrapInIdentityPkcs7(const char *src, char *dst, size_t dlen);
rc_t Base64InIdentityPkcs7(const char *src, char *dst, size_t dlen);
rc_t MakeLocation(const char *pkcs7, const char *document, char *dst, size_t dlen);

rc_t GetPkcs7( const struct AWS * self, char *dst, size_t dlen );

#ifdef __cplusplus
}
#endif
